@@ -5,7 +5,7 @@
 #       University of Pavia - Italy                           #
 #       www.labmedinfo.org                                    #
 #                                                             #
-#   $Id: dtw.R 178 2008-09-25 17:35:05Z tonig $
+#   $Id: dtw.R 234 2009-06-30 13:07:37Z tonig $
 #                                                             #
 ###############################################################
 
@@ -205,6 +205,17 @@ is.dtw <- function(d) {
 
 
 
+##############################
+## OO print method
+print.dtw <- function(x,...) {
+  head <- "DTW alignment object\n";
+  size <- sprintf("Alignment size (query x reference): %d x %d\n",x$N,x$M);
+  call <- sprintf("Call: %s\n",deparse(x$call));
+  cat(head,size,call);
+}
+
+
+
 
 ## Replace  char window.type  with appropriate
 ## windowing FUNCTION 
